"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Endpoint = void 0;
const encode = encodeURIComponent;
exports.Endpoint = {
    CONTRIBUTORS: 'contributors',
    DEPENDENCIES: 'dependencies',
    DEPENDENT_REPOSITORIES: 'dependent_repositories',
    DEPENDENTS: 'dependents',
    GITHUB: 'github',
    PLATFORMS: 'platforms',
    PROJECT_CONTRIBUTIONS: 'project-contributions',
    PROJECTS: 'projects',
    REPOSITORIES: 'repositories',
    REPOSITORY_CONTRIBUTIONS: 'repository-contributions',
    SEARCH: 'search',
    SOURCERANK: 'sourcerank',
    SUBSCRIPTIONS: 'subscriptions',
    USAGE: 'usage',
    Project: {
        contributors(platform, name) {
            return `/${encode(platform)}/${encode(name)}/${exports.Endpoint.CONTRIBUTORS}/`;
        },
        dependencies(platform, name, version) {
            return `/${encode(platform)}/${encode(name)}/${encode(version)}/${exports.Endpoint.DEPENDENCIES}/`;
        },
        dependentRepositories(platform, name) {
            return `/${encode(platform)}/${encode(name)}/${exports.Endpoint.DEPENDENT_REPOSITORIES}/`;
        },
        dependents(platform, name) {
            return `/${encode(platform)}/${encode(name)}/${exports.Endpoint.DEPENDENTS}/`;
        },
        search() {
            return `/${exports.Endpoint.SEARCH}/`;
        },
        sourceRank(platform, name) {
            return `/${encode(platform)}/${encode(name)}/${exports.Endpoint.SOURCERANK}/`;
        },
        subscriptions(platform, name) {
            return `/${exports.Endpoint.SUBSCRIPTIONS}/${encode(platform)}/${encode(name)}/`;
        },
        usage(platform, name) {
            return `/${encode(platform)}/${encode(name)}/${exports.Endpoint.USAGE}/`;
        },
        project(platform, name) {
            return `/${encode(platform)}/${encode(name)}/`;
        },
    },
    GitHub: {
        Repository: {
            dependencies(owner, name) {
                return `/${exports.Endpoint.GITHUB}/${encode(owner)}/${encode(name)}/${exports.Endpoint.DEPENDENCIES}/`;
            },
            projects(owner, name) {
                return `/${exports.Endpoint.GITHUB}/${encode(owner)}/${encode(name)}/${exports.Endpoint.PROJECTS}/`;
            },
            repository(owner, name) {
                return `/${exports.Endpoint.GITHUB}/${encode(owner)}/${encode(name)}/`;
            },
        },
        User: {
            dependencies(login) {
                return `/${exports.Endpoint.GITHUB}/${encode(login)}/${exports.Endpoint.DEPENDENCIES}/`;
            },
            packages(login) {
                return `/${exports.Endpoint.GITHUB}/${encode(login)}/${exports.Endpoint.PROJECTS}/`;
            },
            projects(login) {
                return `/${exports.Endpoint.GITHUB}/${encode(login)}/${exports.Endpoint.PROJECTS}/`;
            },
            contributedProjects(login) {
                return `/${exports.Endpoint.GITHUB}/${encode(login)}/${exports.Endpoint.PROJECT_CONTRIBUTIONS}/`;
            },
            repositories(login) {
                return `/${exports.Endpoint.GITHUB}/${encode(login)}/${exports.Endpoint.REPOSITORIES}/`;
            },
            contributedRepositories(login) {
                return `/${exports.Endpoint.GITHUB}/${encode(login)}/${exports.Endpoint.REPOSITORY_CONTRIBUTIONS}/`;
            },
            user(login) {
                return `/${exports.Endpoint.GITHUB}/${encode(login)}/`;
            },
        }
    },
    platforms() {
        return `/${exports.Endpoint.PLATFORMS}/`;
    },
    subscriptions(platform, name) {
        let endpoint = `/${exports.Endpoint.SUBSCRIPTIONS}/`;
        if (platform && name) {
            endpoint += `${encode(platform)}/${encode(name)}/`;
        }
        return endpoint;
    }
};
//# sourceMappingURL=Endpoints.js.map